@@ -6,10 +6,10 @@
 # Copyright 2013, John McNamara, jmcnamara@cpan.org
 #
 from datetime import datetime
-from xlsxwriter.workbook import Workbook
+import xlsxwriter
 
 # Create a workbook and add a worksheet.
-workbook = Workbook('datetimes.xlsx')
+workbook = xlsxwriter.Workbook('datetimes.xlsx')
 worksheet = workbook.add_worksheet()
 bold = workbook.add_format({'bold': True})
 
