@@ -6,6 +6,7 @@
 #
 
 # Standard packages.
+import sys
 import re
 import os
 import tempfile
@@ -783,16 +784,29 @@ class Workbook(xmlwriter.XMLwriter):
         marker3 = (unpack('4s', data[6:10]))[0]
         marker4 = (unpack('2s', data[:2]))[0]
 
-        if marker1 == b'PNG':
+        if sys.version_info < (2, 6, 0):
+            # Python 2.5/Jython.
+            png_marker = 'PNG'
+            jfif_marker = 'JFIF'
+            exif_marker = 'EXIF'
+            bmp_marker = 'BM'
+        else:
+            # Eval the binary literals for Python 2.5/Jython compatibility.
+            png_marker = eval("b'PNG'")
+            jfif_marker = eval("b'JFIF'")
+            exif_marker = eval("b'EXIF'")
+            bmp_marker = eval("b'BM'")
+
+        if marker1 == png_marker:
             self.image_types['png'] = 1
             (image_type, width, height) = self._process_png(data)
 
         elif (marker2 == 0xFFD8 and
-              (marker3 == b'JFIF' or marker3 == b'EXIF')):
+              (marker3 == jfif_marker or marker3 == exif_marker)):
             self.image_types['jpeg'] = 1
             (image_type, width, height) = self._process_jpg(data)
 
-        elif (marker4 == b'BM'):
+        elif (marker4 == bmp_marker):
             self.image_types['bmp'] = 1
             (image_type, width, height) = self._process_bmp(data)
 
@@ -889,10 +903,8 @@ class Workbook(xmlwriter.XMLwriter):
         else:
             return None
 
-    #
-    # Iterate through the worksheets and set up the VML objects.
-    #
     def _prepare_vml(self):
+        # Iterate through the worksheets and set up the VML objects.
         comment_id = 0
         vml_data_id = 1
         vml_shape_id = 1024
